;; Generated package description from plz.el  -*- no-byte-compile: t -*-
(define-package "plz" "0.5.4.0.20230415.212827" "HTTP library" '((emacs "26.3")) :commit "367c6a5a9a4bf320dcccb54bdd80ac46aa8be06f" :authors '(("Adam Porter" . "adam@alphapapa.net")) :maintainer '("Adam Porter" . "adam@alphapapa.net") :keywords '("comm" "network" "http") :url "https://github.com/alphapapa/plz.el")
